window.Gleam.initSearch([{"doc":"shellout","title":"shellout","content":"# shellout 🐢\n\n[![Hex Package](https://img.shields.io/hexpm/v/shellout?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/shellout)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/shellout/)\n[![License](https://img.shields.io/hexpm/l/shellout?color=ffaff3&amp;label=%F0%9F%93%83)](https://github.com/tynanbe/shellout/blob/main/LICENSE)\n[![Build](https://img.shields.io/github/actions/workflow/status/tynanbe/shellout/ci.yml?branch=main&amp;color=ffaff3&amp;label=%E2%9C%A8)](https://github.com/tynanbe/shellout/actions)\n\nA Gleam library for cross-platform shell operations.\n\n&lt;br&gt;\n\n## Usage\n\n### Example\n\n• In `my_project/src/my_project.gleam`\n\n```gleam\nimport gleam/io\nimport gleam/map\nimport shellout.{Lookups}\n\npub const lookups: Lookups = [\n  #(\n    [&quot;color&quot;, &quot;background&quot;],\n    [\n      #(&quot;buttercup&quot;, [&quot;252&quot;, &quot;226&quot;, &quot;174&quot;]),\n      #(&quot;mint&quot;, [&quot;182&quot;, &quot;255&quot;, &quot;234&quot;]),\n      #(&quot;pink&quot;, [&quot;255&quot;, &quot;175&quot;, &quot;243&quot;]),\n    ],\n  ),\n]\n\npub fn main() {\n  let result =\n    shellout.arguments()\n    |&gt; shellout.command(run: &quot;ls&quot;, with: _, in: &quot;.&quot;, opt: [])\n\n  let status = case result {\n    Ok(output) -&gt; {\n      io.print(output)\n      0\n    }\n    Error(#(status, message)) -&gt; {\n      message\n      |&gt; shellout.style(\n        with: shellout.display([&quot;bold&quot;, &quot;italic&quot;])\n        |&gt; map.merge(shellout.color([&quot;pink&quot;]))\n        |&gt; map.merge(shellout.background([&quot;brightblack&quot;])),\n        custom: lookups,\n      )\n      |&gt; io.print\n      status\n    }\n  }\n\n  shellout.exit(status)\n}\n```\n\n### 🐚 You can test the above example with your shell!\n\n• In your terminal\n\n```shell\n&gt; cd my_project\n&gt; gleam run -- -lah\n# ..\n&gt; gleam run -- --lah\n# ..\n&gt; gleam run --target=javascript -- -lah\n# ..\n&gt; gleam run --target=javascript -- --lah\n# ..\n```\n\n&lt;br&gt;\n\n## Installation\n\n### As a dependency of your Gleam project\n\n• Add `shellout` to `gleam.toml`\n\n```toml\n[dependencies]\nshellout = &quot;~&gt; 1.1&quot;\n```\n\n### As a dependency of your Mix project\n\n• Add `shellout` to `mix.exs`\n\n```elixir\ndefp deps do\n  [\n    {:shellout, &quot;~&gt; 1.1&quot;},\n  ]\nend\n```\n\n### As a dependency of your Rebar3 project\n\n• Add `shellout` to `rebar.config`\n\n```erlang\n{deps, [\n  {shellout, &quot;1.1.0&quot;}\n]}.\n```\n","url":"index.html"},{"doc":"shellout","title":"CommandOpt","content":"pub type CommandOpt {\n  LetBeStderr\n  LetBeStdout\n  OverlappedStdio\n}\n Options for controlling the behavior of [`command`](#command).\n\nLetBeStderr\n Don&#39;t capture the standard error stream, let it behave as usual.\n\n\nLetBeStdout\n Don&#39;t capture the standard output stream, let it behave as usual.\n\n When targeting Erlang, this option also implies `LetBeStderr`.\n\n When targeting JavaScript, this option also enables `SIGINT` (`Ctrl+C`) to\n pass through to the spawned process.\n\n\nOverlappedStdio\n Overlap the standard input and output streams.\n\n This option is specific to the Windows platform and otherwise ignored;\n however, when targeting JavaScript, this option prevents the standard\n input stream from behaving as usual.\n\n\nSynonyms:\nshellout.CommandOpt\nshellout CommandOpt","url":"shellout.html#CommandOpt"},{"doc":"shellout","title":"Lookup","content":"pub type Lookup =\n  List(#(String, List(String)))\n A list of tuples in which the first element of each tuple is a label and the\n second element is a list of one or more number strings representing a\n singular ANSI style.\n\n ANSI styles are split into three categories, labeled `&quot;display&quot;`, `&quot;color&quot;`,\n and `&quot;background&quot;`, primarily so a single color `Lookup` can work with both\n foreground and background.\n\n ## Examples\n\n See the [`displays`](#displays) and [`colors`](#colors) constants, and the\n [`Lookups`](#Lookups) type.\n\n\nSynonyms:\nshellout.Lookup\nshellout Lookup","url":"shellout.html#Lookup"},{"doc":"shellout","title":"Lookups","content":"pub type Lookups =\n  List(#(List(String), Lookup))\n A list of tuples in which the first element of each tuple is a list of\n [`Lookup`](#Lookup) labels and the second element is a [`Lookup`](#Lookup).\n\n `Lookups` allow for customization, adding new styles to the specified\n [`Lookup`](#Lookup) categories.\n\n ## Examples\n\n \n pub const lookups: Lookups = [\n   #(\n     [&quot;color&quot;, &quot;background&quot;],\n     [\n       #(&quot;buttercup&quot;, [&quot;252&quot;, &quot;226&quot;, &quot;174&quot;]),\n       #(&quot;mint&quot;, [&quot;182&quot;, &quot;255&quot;, &quot;234&quot;]),\n       #(&quot;pink&quot;, [&quot;255&quot;, &quot;175&quot;, &quot;243&quot;]),\n     ],\n   ),\n ]\n \n\n\nSynonyms:\nshellout.Lookups\nshellout Lookups","url":"shellout.html#Lookups"},{"doc":"shellout","title":"StyleFlags","content":"pub type StyleFlags =\n  Map(String, List(String))\n A map in which the keys are style categories, `&quot;display&quot;`, `&quot;color&quot;`, or\n `&quot;background&quot;`, and the values are lists of style labels found within a\n [`Lookup`](#Lookup).\n\n ## Examples\n\n See the [`display`](#display), [`color`](#color), and\n [`background`](#background) functions.\n\n\nSynonyms:\nshellout.StyleFlags\nshellout StyleFlags","url":"shellout.html#StyleFlags"},{"doc":"shellout","title":"colors","content":"pub const colors: List(#(String, List(String))) = [\n  #(&quot;black&quot;, [&quot;30&quot;]),\n  #(&quot;red&quot;, [&quot;31&quot;]),\n  #(&quot;green&quot;, [&quot;32&quot;]),\n  #(&quot;yellow&quot;, [&quot;33&quot;]),\n  #(&quot;blue&quot;, [&quot;34&quot;]),\n  #(&quot;magenta&quot;, [&quot;35&quot;]),\n  #(&quot;cyan&quot;, [&quot;36&quot;]),\n  #(&quot;white&quot;, [&quot;37&quot;]),\n  #(&quot;default&quot;, [&quot;39&quot;]),\n  #(&quot;brightblack&quot;, [&quot;90&quot;]),\n  #(&quot;brightred&quot;, [&quot;91&quot;]),\n  #(&quot;brightgreen&quot;, [&quot;92&quot;]),\n  #(&quot;brightyellow&quot;, [&quot;93&quot;]),\n  #(&quot;brightblue&quot;, [&quot;94&quot;]),\n  #(&quot;brightmagenta&quot;, [&quot;95&quot;]),\n  #(&quot;brightcyan&quot;, [&quot;96&quot;]),\n  #(&quot;brightwhite&quot;, [&quot;97&quot;]),\n]\n A list of ANSI styles representing the basic 16 terminal colors, 8 standard\n and 8 bright.\n\nSynonyms:\nshellout.colors\nshellout colors","url":"shellout.html#colors"},{"doc":"shellout","title":"displays","content":"pub const displays: List(#(String, List(String))) = [\n  #(&quot;reset&quot;, [&quot;0&quot;]),\n  #(&quot;bold&quot;, [&quot;1&quot;]),\n  #(&quot;dim&quot;, [&quot;2&quot;]),\n  #(&quot;italic&quot;, [&quot;3&quot;]),\n  #(&quot;underline&quot;, [&quot;4&quot;]),\n  #(&quot;blink&quot;, [&quot;5&quot;]),\n  #(&quot;fastblink&quot;, [&quot;6&quot;]),\n  #(&quot;reverse&quot;, [&quot;7&quot;]),\n  #(&quot;hide&quot;, [&quot;8&quot;]),\n  #(&quot;strike&quot;, [&quot;9&quot;]),\n  #(&quot;normal&quot;, [&quot;22&quot;]),\n  #(&quot;noitalic&quot;, [&quot;23&quot;]),\n  #(&quot;nounderline&quot;, [&quot;24&quot;]),\n  #(&quot;noblink&quot;, [&quot;25&quot;]),\n  #(&quot;noreverse&quot;, [&quot;27&quot;]),\n  #(&quot;nohide&quot;, [&quot;28&quot;]),\n  #(&quot;nostrike&quot;, [&quot;29&quot;]),\n]\n A list of ANSI styles representing non-color display effects.\n\nSynonyms:\nshellout.displays\nshellout displays","url":"shellout.html#displays"},{"doc":"shellout","title":"arguments","content":"pub fn arguments() -&gt; List(String)\n Retrieves a list of strings corresponding to any extra arguments passed when\n invoking a runtime—via `gleam run`, for example.\n\n ## Examples\n\n \n // $ gleam run -- pizza --order=5 --anchovies=false\n &gt; arguments()\n [&quot;pizza&quot;, &quot;--order=5&quot;, &quot;--anchovies=false&quot;]\n \n\n \n // $ gleam run --target=javascript\n &gt; arguments()\n []\n \n\nSynonyms:\nshellout.arguments\nshellout arguments","url":"shellout.html#arguments"},{"doc":"shellout","title":"background","content":"pub fn background(values: List(String)) -&gt; Map(\n  String,\n  List(String),\n)\n Converts a list of `&quot;background&quot;` style labels into a\n [`StyleFlags`](#StyleFlags).\n\n ## Examples\n\n \n &gt; style(\n &gt;   &quot;awesome&quot;,\n &gt;   with: background([&quot;yellow&quot;, &quot;brightgreen&quot;, &quot;bodacious&quot;]),\n &gt;   custom: [],\n &gt; )\n &quot;\\e[43;102mawesome\\e[0m\\e[K&quot;\n \n\nSynonyms:\nshellout.background\nshellout background","url":"shellout.html#background"},{"doc":"shellout","title":"color","content":"pub fn color(values: List(String)) -&gt; Map(String, List(String))\n Converts a list of `&quot;color&quot;` style labels into a\n [`StyleFlags`](#StyleFlags).\n\n ## Examples\n\n \n &gt; style(\n &gt;   &quot;uh...&quot;,\n &gt;   with: color([&quot;yellow&quot;, &quot;brightgreen&quot;, &quot;gnarly&quot;]),\n &gt;   custom: [],\n &gt; )\n &quot;\\e[33;92muh...\\e[0m\\e[K&quot;\n \n\nSynonyms:\nshellout.color\nshellout color","url":"shellout.html#color"},{"doc":"shellout","title":"command","content":"pub fn command(run executable: String, with arguments: List(\n    String,\n  ), in directory: String, opt options: List(CommandOpt)) -&gt; Result(\n  String,\n  #(Int, String),\n)\n Results in any output captured from the given `executable` on success, or an\n `Error` on failure.\n\n An `Error` result wraps a tuple in which the first element is an OS error\n status code and the second is a message about what went wrong (or an empty\n string).\n\n The `executable` is given `arguments` and run from within the given\n `directory`.\n\n Any number of [`CommandOpt`](#CommandOpt) options can be given to alter the\n behavior of this function.\n\n The standard error stream is by default redirected to the standard output\n stream, and both are captured. When targeting JavaScript, anything captured\n from the standard error stream is appended to anything captured from the\n standard output stream.\n\n The standard input stream is by default handled in\n [raw mode](https://www.wikiwand.com/en/Terminal_mode) when targeting\n JavaScript, allowing full interaction with the spawned process. When\n targeting Erlang, however, it&#39;s always handled in\n [cooked mode](https://www.wikiwand.com/en/Terminal_mode).\n\n Note that while `shellout` aims for near feature parity between runtimes,\n some discrepancies exist and are documented herein.\n\n ## Examples\n\n \n &gt; command(run: &quot;echo&quot;, with: [&quot;-n&quot;, &quot;Cool!&quot;], in: &quot;.&quot;, opt: [])\n Ok(&quot;Cool!&quot;)\n \n\n \n &gt; command(run: &quot;echo&quot;, with: [&quot;Cool!&quot;], in: &quot;.&quot;, opt: [LetBeStdout])\n // Cool!\n Ok(&quot;&quot;)\n \n\n \n // $ stat -c &#39;%a %U %n&#39; /tmp/dimension_x\n // 700 root /tmp/dimension_x\n &gt; command(run: &quot;ls&quot;, with: [&quot;dimension_x&quot;], in: &quot;/tmp&quot;, opt: [])\n Error(#(2, &quot;ls: cannot open directory &#39;dimension_x&#39;: Permission denied\\n&quot;))\n \n\n \n &gt; command(run: &quot;dimension_X&quot;, with: [], in: &quot;.&quot;, opt: [])\n Error(#(1, &quot;command `dimension_x` not found\\n&quot;))\n \n\n \n // $ ls -p\n // gleam.toml  manifest.toml  src/  test/\n &gt; command(run: &quot;echo&quot;, with: [], in: &quot;dimension_x&quot;, opt: [])\n Error(#(2, &quot;The directory \\&quot;dimension_x\\&quot; does not exist\\n&quot;))\n \n\nSynonyms:\nshellout.command\nshellout command","url":"shellout.html#command"},{"doc":"shellout","title":"display","content":"pub fn display(values: List(String)) -&gt; Map(String, List(String))\n Converts a list of `&quot;display&quot;` style labels into a\n [`StyleFlags`](#StyleFlags).\n\n ## Examples\n\n \n &gt; style(\n &gt;   &quot;radical&quot;,\n &gt;   with: display([&quot;bold&quot;, &quot;italic&quot;, &quot;tubular&quot;]),\n &gt;   custom: [],\n &gt; )\n &quot;\\e[1;3mradical\\e[0m\\e[K&quot;\n \n\nSynonyms:\nshellout.display\nshellout display","url":"shellout.html#display"},{"doc":"shellout","title":"exit","content":"pub fn exit(status: Int) -&gt; Nil\n Halts the runtime and passes the given `status` code to the operating\n system.\n\n A `status` code of `0` typically indicates success, while any other integer\n represents an error.\n\n ## Examples\n\n \n // $ gleam run &amp;&amp; echo &quot;Pizza time!&quot;\n &gt; exit(0)\n // Pizza time!\n \n\n \n // $ gleam run || echo &quot;Ugh, shell shock ...&quot;\n &gt; exit(1)\n // Ugh, shell shock ...\n \n\nSynonyms:\nshellout.exit\nshellout exit","url":"shellout.html#exit"},{"doc":"shellout","title":"style","content":"pub fn style(string: String, with flags: Map(String, List(String)), custom lookups: List(\n    #(List(String), List(#(String, List(String)))),\n  )) -&gt; String\n Applies ANSI styles to a string, resetting styling at the end.\n\n If a style label isn&#39;t found within a [`Lookup`](#Lookup) associated with\n the corresponding [`StyleFlags`](#StyleFlags) key&#39;s category, that label is\n silently ignored.\n\n ## Examples\n\n \n &gt; import gleam/map\n &gt; pub const lookups: Lookups = [\n &gt;   #(\n &gt;     [&quot;color&quot;, &quot;background&quot;],\n &gt;     [\n &gt;       #(&quot;buttercup&quot;, [&quot;252&quot;, &quot;226&quot;, &quot;174&quot;]),\n &gt;       #(&quot;mint&quot;, [&quot;182&quot;, &quot;255&quot;, &quot;234&quot;]),\n &gt;       #(&quot;pink&quot;, [&quot;255&quot;, &quot;175&quot;, &quot;243&quot;]),\n &gt;     ],\n &gt;   ),\n &gt; ]\n &gt; style(\n &gt;   &quot;cowabunga&quot;,\n &gt;   with: display([&quot;bold&quot;, &quot;italic&quot;, &quot;awesome&quot;])\n &gt;   |&gt; map.merge(color([&quot;pink&quot;, &quot;righteous&quot;]))\n &gt;   |&gt; map.merge(background([&quot;brightblack&quot;, &quot;excellent&quot;])),\n &gt;   custom: lookups,\n &gt; )\n &quot;\\e[1;3;38;2;255;175;243;100mcowabunga\\e[0m\\e[K&quot;\n \n\nSynonyms:\nshellout.style\nshellout style","url":"shellout.html#style"},{"doc":"shellout","title":"which","content":"pub fn which(executable: String) -&gt; Result(String, String)\n Results in a path to the given `executable` on success, or an `Error` when\n no such path is found.\n\n ## Examples\n\n \n &gt; which(&quot;echo&quot;)\n Ok(&quot;/sbin/echo&quot;)\n \n\n \n &gt; which(&quot;./priv/party&quot;)\n Ok(&quot;./priv/party&quot;)\n \n\n \n &gt; which(&quot;dimension_x&quot;)\n Error(&quot;command `dimension_x` not found&quot;)\n \n\nSynonyms:\nshellout.which\nshellout which","url":"shellout.html#which"},{"doc":"shellout","title":"shellout","content":"","url":"shellout.html"}]);